"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Agile = void 0;
const internal_1 = require("./internal");
class Agile {
    constructor(config = {}) {
        config = internal_1.defineConfig(config, {
            localStorage: false,
            waitForMount: true,
            bindGlobal: false,
            autoIntegrate: true,
            bucket: true,
        });
        this.config = {
            waitForMount: config.waitForMount,
            bucket: config.bucket,
        };
        this.key = config.key;
        this.integrations = new internal_1.Integrations(this, {
            autoIntegrate: config.autoIntegrate,
        });
        this.runtime = new internal_1.Runtime(this);
        this.subController = new internal_1.SubController(this);
        this.storages = new internal_1.Storages(this, {
            localStorage: config.localStorage,
        });
        internal_1.LogCodeManager.log('10:00:00', [], this);
        if (config.bindGlobal)
            if (!internal_1.globalBind(Agile.globalKey, this)) {
                internal_1.LogCodeManager.log('10:02:00');
            }
    }
    createStorage(config) {
        return internal_1.createStorage(config);
    }
    createState(initialValue, config = {}) {
        return internal_1.createState(initialValue, internal_1.defineConfig(config, {
            agileInstance: this,
        }));
    }
    createCollection(config) {
        return internal_1.createCollection(config, this);
    }
    createComputed(computeFunction, configOrDeps) {
        let _config = {};
        if (Array.isArray(configOrDeps)) {
            _config = internal_1.defineConfig(_config, {
                computedDeps: configOrDeps,
                agileInstance: this,
            });
        }
        else {
            if (configOrDeps)
                _config = internal_1.defineConfig(configOrDeps, {
                    agileInstance: this,
                });
        }
        return internal_1.createComputed(computeFunction, _config);
    }
    integrate(integration) {
        this.integrations.integrate(integration);
        return this;
    }
    registerStorage(storage, config = {}) {
        this.storages.register(storage, config);
        return this;
    }
    hasIntegration() {
        return this.integrations.hasIntegration();
    }
    hasStorage() {
        return this.storages.hasStorage();
    }
}
exports.Agile = Agile;
Agile.globalKey = '__agile__';
