"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Item = void 0;
const internal_1 = require("../internal");
class Item extends internal_1.State {
    constructor(collection, data, config = {}) {
        super(collection.agileInstance(), data, {
            isPlaceholder: config.isPlaceholder,
            key: data[collection.config.primaryKey],
        });
        this.selectedBy = new Set();
        this.collection = () => collection;
        if (this._key != null) {
            this.addRebuildGroupThatIncludeItemKeySideEffect(this._key);
        }
    }
    setKey(value, config = {}) {
        super.setKey(value);
        config = internal_1.defineConfig(config, {
            sideEffects: {
                enabled: true,
                exclude: [],
            },
            background: false,
            force: false,
            storage: true,
            overwrite: false,
        });
        if (value == null)
            return this;
        this.removeSideEffect(Item.updateGroupSideEffectKey);
        this.addRebuildGroupThatIncludeItemKeySideEffect(value);
        this.patch({ [this.collection().config.primaryKey]: value }, config);
        return this;
    }
    persist(keyOrConfig = {}, config = {}) {
        let _config;
        let key;
        if (internal_1.isValidObject(keyOrConfig)) {
            _config = keyOrConfig;
            key = this._key;
        }
        else {
            _config = config || {};
            key = keyOrConfig;
        }
        _config = internal_1.defineConfig(_config, {
            loadValue: true,
            followCollectionPersistKeyPattern: true,
            storageKeys: [],
            defaultStorageKey: null,
        });
        if (_config.followCollectionPersistKeyPattern) {
            key = internal_1.CollectionPersistent.getItemStorageKey(key || this._key, this.collection()._key);
        }
        super.persist(key, {
            loadValue: _config.loadValue,
            storageKeys: _config.storageKeys,
            defaultStorageKey: _config.defaultStorageKey,
        });
        return this;
    }
    addRebuildGroupThatIncludeItemKeySideEffect(itemKey) {
        this.addSideEffect(Item.updateGroupSideEffectKey, (instance, config) => {
            instance.collection().rebuildGroupsThatIncludeItemKey(itemKey, config);
        }, { weight: 100 });
    }
}
exports.Item = Item;
Item.updateGroupSideEffectKey = 'rebuildGroup';
