export declare let loggerPackage: any;
declare const logCodeMessages: {
    '10:00:00': string;
    '10:02:00': string;
    '11:02:00': string;
    '11:02:01': string;
    '11:03:00': string;
    '11:03:01': string;
    '11:03:02': string;
    '11:03:03': string;
    '11:03:04': string;
    '11:03:05': string;
    '12:03:00': string;
    '12:03:01': string;
    '12:03:02': string;
    '13:00:00': string;
    '13:01:00': string;
    '13:01:01': string;
    '13:01:02': string;
    '13:02:00': string;
    '13:03:00': string;
    '14:02:00': string;
    '14:03:00': string;
    '14:03:01': string;
    '14:03:02': string;
    '14:03:03': string;
    '14:03:04': string;
    '15:01:00': string;
    '15:01:01': string;
    '15:01:02': string;
    '15:01:03': string;
    '16:01:00': string;
    '16:01:01': string;
    '16:01:02': string;
    '16:02:00': string;
    '16:02:01': string;
    '17:03:00': string;
    '18:00:00': string;
    '18:02:00': string;
    '18:03:00': string;
    '19:03:00': string;
    '1A:02:00': string;
    '1A:02:01': string;
    '1B:02:00': string;
    '1B:02:01': string;
    '1B:02:02': string;
    '1B:02:03': string;
    '1B:02:04': string;
    '1B:02:05': string;
    '1B:03:00': string;
    '1B:03:01': string;
    '1B:03:02': string;
    '1B:03:03': string;
    '1B:03:04': string;
    '1B:03:05': string;
    '1B:03:06': string;
    '1C:02:00': string;
    '1C:03:00': string;
    '1C:03:01': string;
    '20:03:00': string;
    '20:03:01': string;
    '20:03:02': string;
    '00:03:00': string;
    '00:03:01': string;
};
/**
 * Returns the log message according to the specified log code.
 *
 * @internal
 * @param logCode - Log code of the message to be returned.
 * @param replacers - Instances that replace these '${x}' placeholders based on the index
 * For example: 'replacers[0]' replaces '${0}', 'replacers[1]' replaces '${1}', ..
 */
declare function getLog<T extends LogCodesArrayType<typeof logCodeMessages>>(logCode: T, replacers?: any[]): string;
/**
 * Logs the log message according to the specified log code
 * with the Agile Logger if installed or the normal console.
 *
 * @internal
 * @param logCode - Log code of the message to be returned.
 * @param replacers - Instances that replace these '${x}' placeholders based on the index
 * For example: 'replacers[0]' replaces '${0}', 'replacers[1]' replaces '${1}', ..
 * @param data - Data to be attached to the end of the log message.
 */
declare function log<T extends LogCodesArrayType<typeof logCodeMessages>>(logCode: T, replacers?: any[], ...data: any[]): void;
/**
 * Logs the log message according to the specified log code
 * with the Agile Logger if installed and the provided tags are active.
 *
 * @internal
 * @param tags - Tags to be active to log the logCode.
 * @param logCode - Log code of the message to be returned.
 * @param replacers - Instances that replace these '${x}' placeholders based on the index
 * For example: 'replacers[0]' replaces '${0}', 'replacers[1]' replaces '${1}', ..
 * @param data - Data to be attached to the end of the log message.
 */
declare function logIfTags<T extends LogCodesArrayType<typeof logCodeMessages>>(tags: string[], logCode: T, replacers?: any[], ...data: any[]): void;
/**
 * The Log Code Manager keeps track
 * and manages all important Logs of AgileTs.
 *
 * @internal
 */
export declare const LogCodeManager: {
    getLog: typeof getLog;
    log: typeof log;
    logCodeLogTypes: {
        '00': string;
        '01': string;
        '02': string;
        '03': string;
    };
    logCodeMessages: {
        '10:00:00': string;
        '10:02:00': string;
        '11:02:00': string;
        '11:02:01': string;
        '11:03:00': string;
        '11:03:01': string;
        '11:03:02': string;
        '11:03:03': string;
        '11:03:04': string;
        '11:03:05': string;
        '12:03:00': string;
        '12:03:01': string;
        '12:03:02': string;
        '13:00:00': string;
        '13:01:00': string;
        '13:01:01': string;
        '13:01:02': string;
        '13:02:00': string;
        '13:03:00': string;
        '14:02:00': string;
        '14:03:00': string;
        '14:03:01': string;
        '14:03:02': string;
        '14:03:03': string;
        '14:03:04': string;
        '15:01:00': string;
        '15:01:01': string;
        '15:01:02': string;
        '15:01:03': string;
        '16:01:00': string;
        '16:01:01': string;
        '16:01:02': string;
        '16:02:00': string;
        '16:02:01': string;
        '17:03:00': string;
        '18:00:00': string;
        '18:02:00': string;
        '18:03:00': string;
        '19:03:00': string;
        '1A:02:00': string;
        '1A:02:01': string;
        '1B:02:00': string;
        '1B:02:01': string;
        '1B:02:02': string;
        '1B:02:03': string;
        '1B:02:04': string;
        '1B:02:05': string;
        '1B:03:00': string;
        '1B:03:01': string;
        '1B:03:02': string;
        '1B:03:03': string;
        '1B:03:04': string;
        '1B:03:05': string;
        '1B:03:06': string;
        '1C:02:00': string;
        '1C:03:00': string;
        '1C:03:01': string;
        '20:03:00': string;
        '20:03:01': string;
        '20:03:02': string;
        '00:03:00': string;
        '00:03:01': string;
    };
    getLogger: () => any;
    logIfTags: typeof logIfTags;
};
export declare type LogCodesArrayType<T> = {
    [K in keyof T]: T[K] extends string ? K : never;
}[keyof T] & string;
export {};
